@@ -1,18 +1,19 @@
 """
 widgets for django-markitup
 
-Time-stamp: <2011-04-19 19:03:14 carljm widgets.py>
+Time-stamp: <2011-11-26 14:39:52 carljm widgets.py>
 
 """
 from django import forms
 from django.utils.safestring import mark_safe
 from django.contrib.admin.widgets import AdminTextareaWidget
+from django.core.urlresolvers import reverse, NoReverseMatch
 
 from markitup import settings
 from markitup.util import absolute_url
 import posixpath
 
-class MarkupTextarea(forms.Textarea):
+class MarkupInput(forms.Widget):
     def render(self, name, value, attrs=None):
         if value is not None:
             # Special handling for MarkupField value.
@@ -22,7 +23,13 @@ class MarkupTextarea(forms.Textarea):
                 value = value.raw
             except AttributeError:
                 pass
-        return super(MarkupTextarea, self).render(name, value, attrs)
+        return super(MarkupInput, self).render(name, value, attrs)
+
+class MarkupTextarea(MarkupInput, forms.Textarea):
+    pass
+
+class MarkupHiddenWidget(MarkupInput, forms.HiddenInput):
+    pass
 
 
 class MarkItUpWidget(MarkupTextarea):
@@ -52,31 +59,48 @@ class MarkItUpWidget(MarkupTextarea):
         super(MarkItUpWidget, self).__init__(attrs)
 
     def _media(self):
+        js_media = [absolute_url(settings.JQUERY_URL)] if settings.JQUERY_URL is not None else []
+        js_media = js_media + [absolute_url('markitup/ajax_csrf.js'),
+                               absolute_url('markitup/jquery.markitup.js'),
+                               posixpath.join(self.miu_set, 'set.js')]
         return forms.Media(
             css= {'screen': (posixpath.join(self.miu_skin, 'style.css'),
                              posixpath.join(self.miu_set, 'style.css'))},
-            js=(absolute_url(settings.JQUERY_URL),
-                absolute_url('markitup/ajax_csrf.js'),
-                absolute_url('markitup/jquery.markitup.js'),
-                posixpath.join(self.miu_set, 'set.js')))
+            js=js_media)
     media = property(_media)
 
     def render(self, name, value, attrs=None):
         html = super(MarkItUpWidget, self).render(name, value, attrs)
 
+        final_attrs = self.build_attrs(attrs)
+
         if self.auto_preview:
             auto_preview = "$('a[title=\"Preview\"]').trigger('mouseup');"
         else: auto_preview = ''
 
-        html += ('<script type="text/javascript">'
-                '(function($) { '
-                 '$(document).ready(function() {'
-                 '  $("#%(id)s").markItUp(mySettings);'
-                 '  %(auto_preview)s '
-                 '});'
-                 '})(jQuery);'
-                 '</script>' % {'id': attrs['id'],
-                                'auto_preview': auto_preview })
+        try:
+            preview_url = (
+                'mySettings["previewParserPath"] = "%s";'
+                % reverse('markitup_preview'))
+        except NoReverseMatch:
+           preview_url = "";
+
+        html += """
+        <script type="text/javascript">
+        (function($) {
+          $(document).ready(function() {
+            var element = $("#%(id)s");
+            if(!element.hasClass("markItUpEditor")) {
+              %(preview_url)s
+              element.markItUp(mySettings);
+            }
+            %(auto_preview)s
+          });
+          })(jQuery);
+        </script>
+        """ % {'id': final_attrs['id'], 'auto_preview': auto_preview,
+               'preview_url': preview_url}
+
         return mark_safe(html)
 
 
